searchData={"content_type":"text/markdown","items":[{"doc":"`elixir_mlx90640` provides a high level abstraction to interface with the\nMLX90640 Far Infrared Thermal Sensor Array on Linux platforms.","ref":"Mlx90640.html","title":"Mlx90640","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Mlx90640.html#child_spec/1","title":"Mlx90640.child_spec/1","type":"function"},{"doc":"","ref":"Mlx90640.html#init/1","title":"Mlx90640.init/1","type":"function"},{"doc":"Starts and links the `Mlx90640` GenServer.\n\n`receiver` is a process that will receive messages on each frame captured by\nthe sensor.\n\n`frame_rate` is the (approximate) number of frames per second that the sensor\nwill capture. Valid values are 1, 2, 4, 8, 16, 32, and 64. The default is 2.\nHigher values might require a faster I2C baud rate to be configured in Linux.\n\nThe `receiver` process will receive, for each frame captured by the sensor, a\nmessage like `%Mlx90640.Frame{ data: data }`, where `data` is a list of rows,\nand each row is a list of pixel temperature measurements, expressed as\nfloating point numbers indicating the temperature in degrees Celsius.\n\nUnder normal conditions, there should be 24 rows of 32 pixels each, but in\ncase of corrupted data frames there might be less.","ref":"Mlx90640.html#start_link/3","title":"Mlx90640.start_link/3","type":"function"},{"doc":"Gracefully stops the `Mlx90640` GenServer.","ref":"Mlx90640.html#stop/1","title":"Mlx90640.stop/1","type":"function"},{"doc":"","ref":"Mlx90640.html#t:frame_rate/0","title":"Mlx90640.frame_rate/0","type":"type"},{"doc":"# Elixir MLX90640\n\n[![Build Status](https://travis-ci.org/lucaong/elixir_mlx90640.svg?branch=master)](https://travis-ci.org/lucaong/elixir_mlx90640)\n\nAn Elixir library to interface with the MLX90640 Far Infrared Thermal Sensor Array.\n\nAn example of a project using this library is [Nerves Thermal\nCamera](https://github.com/lucaong/nerves_thermal_camera).","ref":"readme.html","title":"Elixir MLX90640","type":"extras"},{"doc":"The package can be installed by adding `elixir_mlx90640` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:elixir_mlx90640, \"~> 0.1.10\"}\n  ]\nend\n```\n\nThe I2C driver needs to be installed for this library to compile (e.g.\n`libi2c-dev` on Debian).","ref":"readme.html#installation","title":"Installation - Elixir MLX90640","type":"extras"},{"doc":"```elixir\nreceiver = self() # a process that will receive the data frames\nMlx90640.start_link(receiver, [ frame_rate: 2 ])\n\n# On each frame, the receiver will receive messages like:\n#\n#   %Mlx90640.Frame{ data:\n#     [\n#       [ 23.83, 24.12, 20.69, ... ],\n#       [ 20.36, 20.74, 20.71, ... ],\n#       ...\n#     ]\n#   }\n#\n# Where data is a list of 24 rows, and rows are lists of 32 temperature\n# measurements\n```\n\nFor more information, read the [API documentation](https://hexdocs.pm/elixir_mlx90640).","ref":"readme.html#usage","title":"Usage - Elixir MLX90640","type":"extras"},{"doc":"This project contains low-level code derived from the [device library provided\nby Melexis](https://github.com/melexis/mlx90640-library), as well as the generic\n[Linux port by Pimoroni](https://github.com/pimoroni/mlx90640-library)","ref":"readme.html#acknowledgements","title":"Acknowledgements - Elixir MLX90640","type":"extras"}]}